@@ -75,6 +75,7 @@ GRL_LOG_DOMAIN_STATIC(libpls_log_domain);
   G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE ","    \
   G_FILE_ATTRIBUTE_STANDARD_TYPE ","            \
   G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","       \
+  G_FILE_ATTRIBUTE_STANDARD_SIZE ","            \
   G_FILE_ATTRIBUTE_TIME_MODIFIED ","            \
   G_FILE_ATTRIBUTE_THUMBNAIL_PATH ","           \
   G_FILE_ATTRIBUTE_THUMBNAILING_FAILED ","      \
@@ -117,36 +118,22 @@ grl_pls_private_free (struct _GrlPlsPrivate *priv)
 {
   g_return_if_fail (priv);
 
-  if (priv->cancellable) {
-    g_object_unref (priv->cancellable);
-    priv->cancellable = NULL;
-  }
-
+  g_clear_object (&priv->cancellable);
   g_free (priv);
 }
 
 static void
 grl_source_browse_spec_free (GrlSourceBrowseSpec *spec)
 {
-  if (spec->source) {
-    g_object_unref (spec->source);
-    spec->source = NULL;
-  }
-
-  if (spec->container) {
-    g_object_unref (spec->container);
-    spec->container = NULL;
-  }
+  g_clear_object (&spec->source);
+  g_clear_object (&spec->container);
 
   if (spec->keys) {
     /* TODO */
     spec->keys = NULL;
   }
 
-  if (spec->options) {
-    g_object_unref (spec->options);
-    spec->options = NULL;
-  }
+  g_clear_object (&spec->options);
 
   if (spec->user_data) {
     struct _GrlPlsPrivate *priv = (struct _GrlPlsPrivate *) spec->user_data;
@@ -833,8 +820,11 @@ grl_pls_browse_by_spec (GrlSource *source,
   /* check if we have the entries cached or not */
   valid_entries = g_object_get_data (G_OBJECT (bs->container), GRL_DATA_PRIV_PLS_VALID_ENTRIES);
   if (valid_entries) {
+    guint id;
+
     GRL_DEBUG ("%s : using cached data bs=%p", __FUNCTION__, bs);
-    g_idle_add ((GSourceFunc) grl_pls_browse_report_results, bs);
+    id = g_idle_add ((GSourceFunc) grl_pls_browse_report_results, bs);
+    g_source_set_name_by_id (id, "[grl-pls] grl_pls_browse_report_results");
     return;
   }
 
@@ -1121,12 +1111,10 @@ file_is_valid_content (GFileInfo *info, gboolean fast, GrlOperationOptions *opti
   }
 
  end:
-  if (file_date)
-    g_date_time_unref (file_date);
-  if (min_date)
-    g_date_time_unref (min_date);
-  if (max_date)
-    g_date_time_unref (max_date);
+  g_clear_pointer (&file_date, g_date_time_unref);
+  g_clear_pointer (&min_date, g_date_time_unref);
+  g_clear_pointer (&max_date, g_date_time_unref);
+
   return is_media;
 }
 
@@ -1310,6 +1298,9 @@ grl_pls_file_to_media (GrlMedia            *content,
       grl_media_set_mime (media, mime);
     }
 
+    /* Size */
+    grl_media_set_size (media, g_file_info_get_size (info));
+
     /* Title */
     str = g_strdup (g_file_info_get_display_name (info));
 
