@@ -445,6 +445,25 @@ grl_config_set_api_token (GrlConfig *config, const gchar *token)
                          token);
 }
 
+/**
+ * grl_config_set_api_token_secret:
+ * @config: the config instance
+ * @secret: the API token
+ *
+ * Set the webservice API token secret in the configuration
+ * (Needed by OAuth)
+ *
+ * Since: 0.2.6
+ */
+void
+grl_config_set_api_token_secret (GrlConfig *config, const gchar *secret)
+{
+  grl_config_set_string (GRL_CONFIG (config),
+                         GRL_CONFIG_KEY_APITOKEN_SECRET,
+                         secret);
+}
+
+
 /**
  * grl_config_set_api_secret:
  * @config: the config instance
@@ -569,6 +588,22 @@ grl_config_get_api_token (GrlConfig *config)
                                 GRL_CONFIG_KEY_APITOKEN);
 }
 
+/**
+ * grl_config_get_api_token_secret:
+ * @config: the config instance
+ *
+ * Returns: the webservice API token secret
+ * (Needed by OAuth)
+ *
+ * Since: 0.2.6
+ */
+gchar *
+grl_config_get_api_token_secret (GrlConfig *config)
+{
+  return grl_config_get_string (GRL_CONFIG (config),
+                                GRL_CONFIG_KEY_APITOKEN_SECRET);
+}
+
 /**
  * grl_config_get_api_secret:
  * @config: the config instance
