@@ -413,6 +413,54 @@ grl_related_keys_get_float (GrlRelatedKeys *relkeys,
   }
 }
 
+/**
+ * grl_related_keys_set_boolean:
+ * @relkeys: set of related keys to change
+ * @key: (type GrlKeyID): key to change or add
+ * @booleanvalue: the new value
+ *
+ * Sets the value associated with @key into @relkeys. @key must have been
+ * registered as a boolean-type key. Old value is replaced by the new one.
+ *
+ * Since: 0.2.3
+ **/
+void
+grl_related_keys_set_boolean (GrlRelatedKeys *relkeys,
+                              GrlKeyID key,
+                              gboolean booleanvalue)
+{
+  GValue value = { 0 };
+  g_value_init (&value, G_TYPE_BOOLEAN);
+  g_value_set_boolean (&value, booleanvalue);
+  grl_related_keys_set (relkeys, key, &value);
+}
+
+/**
+ * grl_related_keys_get_boolean:
+ * @relkeys: set of related keys to inspect
+ * @key: (type GrlKeyID): key to use
+ *
+ * Returns the value associated with @key from @relkeys. If @key has no value,
+ * or value is not a gboolean, or @key is not in @relkeys, then %FALSE is
+ * returned.
+ *
+ * Returns: float value associated with @key, or %FALSE in other case.
+ *
+ * Since: 0.2.3
+ **/
+gboolean
+grl_related_keys_get_boolean (GrlRelatedKeys *relkeys,
+                              GrlKeyID key)
+{
+  const GValue *value = grl_related_keys_get (relkeys, key);
+
+  if (!value || !G_VALUE_HOLDS_BOOLEAN (value)) {
+    return FALSE;
+  } else {
+    return g_value_get_boolean (value);
+  }
+}
+
 /**
  * grl_related_keys_set_binary:
  * @relkeys: set of related keys to change
@@ -502,7 +550,7 @@ grl_related_keys_set_boxed (GrlRelatedKeys *relkeys,
 
   g_return_if_fail (boxed != NULL);
 
-  g_value_init (&value, G_TYPE_STRING);
+  g_value_init (&value, grl_metadata_key_get_type (key));
   g_value_set_boxed (&value, boxed);
   grl_related_keys_set (relkeys, key, &value);
   g_value_unset (&value);
@@ -536,6 +584,25 @@ grl_related_keys_get_boxed (GrlRelatedKeys *relkeys,
   }
 }
 
+/**
+ * grl_related_keys_remove:
+ * @relkeys: set of related keys
+ * @key: (type GrlKeyID): key to remove
+ *
+ * Removes @key from @relkeys set.
+ *
+ * Since: 0.2.3
+ **/
+void
+grl_related_keys_remove (GrlRelatedKeys *relkeys,
+                         GrlKeyID key)
+{
+  g_return_if_fail (GRL_IS_RELATED_KEYS (relkeys));
+  g_return_if_fail (key != GRL_METADATA_KEY_INVALID);
+
+  g_hash_table_remove (relkeys->priv->data, GRLKEYID_TO_POINTER (key));
+}
+
 /**
  * grl_related_keys_has_key:
  * @relkeys: set of related keys to inspect
