@@ -281,7 +281,7 @@ print_version (void)
 {
   g_print ("grl-inspect-" GRL_MAJORMINOR " version " VERSION "\n");
   g_print ("Grilo " VERSION "\n");
-  g_print ("http://live.gnome.org/Grilo\n");
+  g_print ("https://wiki.gnome.org/Projects/Grilo\n");
 }
 
 static void
@@ -515,5 +515,8 @@ main (int argc, char *argv[])
   g_timeout_add_seconds ((guint) delay, run, NULL);
 
   g_main_loop_run (mainloop);
+
+  grl_deinit ();
+
   return 0;
 }
