@@ -413,10 +413,8 @@ browse_history_pop (GrlSource **source, GrlMedia **media)
 static void
 set_cur_browse (GrlSource *source, GrlMedia *media)
 {
-  if (ui_state->cur_source)
-    g_object_unref (ui_state->cur_source);
-  if (ui_state->cur_container)
-    g_object_unref (ui_state->cur_container);
+  g_clear_object (&ui_state->cur_source);
+  g_clear_object (&ui_state->cur_container);
 
   if (source)
     g_object_ref (source);
@@ -430,10 +428,8 @@ set_cur_browse (GrlSource *source, GrlMedia *media)
 static void
 set_cur_resolve (GrlSource *source, GrlMedia *media)
 {
-  if (ui_state->cur_md_source)
-    g_object_unref (ui_state->cur_md_source);
-  if (ui_state->cur_md_media)
-    g_object_unref (ui_state->cur_md_media);
+  g_clear_object (&ui_state->cur_md_source);
+  g_clear_object (&ui_state->cur_md_media);
 
   if (source)
     g_object_ref (source);
@@ -707,9 +703,7 @@ browse_search_query_cb (GrlSource *source,
 			-1);
 
     g_object_unref (media);
-    if (icon) {
-      g_object_unref (icon);
-    }
+    g_clear_object (&icon);
   }
 
   if (remaining == 0) {
@@ -870,12 +864,8 @@ browser_activated_cb (GtkTreeView *tree_view,
   browse_history_push (ui_state->cur_source, ui_state->cur_container);
   browse (source, container);
 
-  if (source) {
-    g_object_unref (source);
-  }
-  if (content) {
-    g_object_unref (content);
-  }
+  g_clear_object (&source);
+  g_clear_object (&content);
 }
 
 static void
@@ -917,6 +907,27 @@ media_type_to_str (GrlMediaType type)
   return g_string_free (s, FALSE);
 }
 
+static char *
+tags_to_str (char **tags)
+{
+  GString *s;
+  guint i;
+
+  if (tags == NULL)
+    return g_strdup ("");
+
+  s = g_string_new (NULL);
+
+  for (i = 0; tags[i] != NULL; i++) {
+    g_string_append (s, tags[i]);
+    g_string_append (s, ", ");
+  }
+
+  if (i > 0)
+    g_string_truncate (s, s->len - 2);
+  return g_string_free (s, FALSE);
+}
+
 static void
 populate_source_metadata (GrlSource *source)
 {
@@ -940,6 +951,7 @@ populate_source_metadata (GrlSource *source)
     int rank;
     GrlMediaType supported_media;
     GIcon *icon;
+    char **tags;
 
     for (i = 0; i < G_N_ELEMENTS (str_props); i++) {
       g_object_get (G_OBJECT (source), str_props[i], &str, NULL);
@@ -952,6 +964,7 @@ populate_source_metadata (GrlSource *source)
                   "rank", &rank,
                   "supported-media", &supported_media,
                   "source-icon", &icon,
+                  "source-tags", &tags,
                   NULL);
 
     str = g_strdup_printf ("%i", auto_split_threshold);
@@ -972,6 +985,11 @@ populate_source_metadata (GrlSource *source)
       g_free (str);
       g_object_unref (icon);
     }
+
+    str = tags_to_str (tags);
+    add_source_metadata (view->metadata_model, "source-tags", str);
+    g_free (str);
+    g_strfreev (tags);
   }
 
   gtk_widget_set_sensitive (view->show_btn, FALSE);
@@ -1042,8 +1060,7 @@ browser_row_selected_cb (GtkTreeView *tree_view,
   }
 
   g_object_unref (source);
-  if (content)
-    g_object_unref (content);
+  g_clear_object (&content);
 }
 
 static void
@@ -1077,8 +1094,7 @@ show_btn_clicked_cb (GtkButton *btn, gpointer user_data)
       GRL_WARNING ("Cannot use '%s' to show '%s'; using default application",
                    g_app_info_get_name (app),
                    ui_state->last_url);
-      g_error_free (error);
-      error = NULL;
+      g_clear_error (&error);
       g_app_info_launch_default_for_uri (ui_state->last_url, NULL, &error);
       if (error) {
         GRL_WARNING ("Cannot use default application to show '%s'. "
@@ -1106,10 +1122,8 @@ back_btn_clicked_cb (GtkButton *btn, gpointer user_data)
   browse_history_pop (&prev_source, &prev_container);
   browse (prev_source, prev_container);
 
-  if (prev_source)
-    g_object_unref (prev_source);
-  if (prev_container)
-    g_object_unref (prev_container);
+  g_clear_object (&prev_source);
+  g_clear_object (&prev_container);
 }
 
 static void
@@ -1264,12 +1278,8 @@ remove_btn_clicked_cb (GtkButton *btn, gpointer user_data)
 
   grl_source_remove (source, media, remove_cb, NULL);
 
-  if (source) {
-    g_object_unref (source);
-  }
-  if (media) {
-    g_object_unref (media);
-  }
+  g_clear_object (&source);
+  g_clear_object (&media);
 }
 
 static void
@@ -1340,9 +1350,7 @@ search_btn_clicked_cb (GtkButton *btn, gpointer user_data)
       search (source, text);
     }
 
-    if (source) {
-      g_object_unref (source);
-    }
+    g_clear_object (&source);
   }
 }
 
@@ -1383,9 +1391,7 @@ query_btn_clicked_cb (GtkButton *btn, gpointer user_data)
     text = gtk_entry_get_text (GTK_ENTRY (view->query_text));
     query (source, text);
 
-    if (source) {
-      g_object_unref (source);
-    }
+    g_clear_object (&source);
   }
 }
 
@@ -1821,6 +1827,16 @@ options_setup (void)
   grl_operation_options_set_flags (default_resolve_options, RESOLVE_FLAGS);
 }
 
+static gboolean
+delete_event_cb (GtkWidget *widget,
+		 GdkEvent  *event,
+		 gpointer   user_data)
+{
+  gtk_widget_hide (widget);
+  gtk_main_quit ();
+  return TRUE;
+}
+
 static void
 ui_setup (void)
 {
@@ -1831,8 +1847,8 @@ ui_setup (void)
   view->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (view->window), WINDOW_TITLE);
   gtk_window_resize (GTK_WINDOW (view->window), 600, 400);
-  g_signal_connect (G_OBJECT (view->window), "destroy",
-                    G_CALLBACK (gtk_main_quit), NULL);
+  g_signal_connect (G_OBJECT (view->window), "delete-event",
+                    G_CALLBACK (delete_event_cb), NULL);
 
   GtkActionGroup *actions = gtk_action_group_new ("actions");
   gtk_action_group_add_actions (actions, entries, G_N_ELEMENTS (entries), NULL);
@@ -2109,16 +2125,7 @@ show_browsable_sources ()
 static void
 free_stack (GList **stack)
 {
-  GList *iter;
-  iter = *stack;
-  while (iter) {
-    if (iter->data) {
-      g_object_unref (iter->data);
-    }
-    iter = g_list_next (iter);
-  }
-  g_list_free (*stack);
-  *stack = NULL;
+  g_list_free_full (*stack, g_object_unref);
 }
 
 static void
@@ -2208,6 +2215,24 @@ content_changed_cb (GrlSource *source,
   }
 }
 
+static void
+metadata_key_added_cb (GrlRegistry *registry,
+                       const gchar *key,
+                       gpointer user_data)
+{
+  gchar *message;
+  guint id;
+
+  message = g_strdup_printf ("New metadata key '%s' has been added", key);
+  id = gtk_statusbar_push (GTK_STATUSBAR (view->statusbar),
+                           view->statusbar_context_id,
+                           message);
+  g_timeout_add_seconds (NOTIFICATION_TIMEOUT,
+                         remove_notification,
+                         GUINT_TO_POINTER (id));
+  g_free (message);
+}
+
 static void
 source_added_cb (GrlRegistry *registry,
                  GrlSource *source,
@@ -2271,6 +2296,8 @@ load_plugins (void)
 		    G_CALLBACK (source_added_cb), NULL);
   g_signal_connect (registry, "source-removed",
 		    G_CALLBACK (source_removed_cb), NULL);
+  g_signal_connect (registry, "metadata-key-added",
+                    G_CALLBACK (metadata_key_added_cb), NULL);
   if (!grl_registry_load_all_plugins (registry, NULL)) {
     g_error ("Failed to load plugins.");
   }
